"""This module contains the GroupCreationResponse domain model."""


from .group import Group


class GroupCreationResponse(Group):
    """The API response domain model for the status of a newly created
    group."""

    pass
